/**
 * This class represents a node to be used in a Queue or Stack.
 * 
 * @author Sameh Fakhouri
 *
 */

public class Node<E> {

	private E data;
	private Node<E> next;
	private Node<E> previous;

	
	/**
	 * Constructor that for the Node class.
	 * 
	 * @param	data	This is the data <b>Object</b> held by the Node.
	 * 
	 * 
	 */
	public Node(E data) {
		this.data = data;
		this.next = null;
		this.previous = null;
	}
	
	/**
	 * Constructor that for the Node class.
	 * 
	 * @param	previous	This is the pointer to the previous Node in the Linked List.
	 * @param	data	This is the data <b>Object</b> held by the Node.
	 * @param	next	This is the pointer to the next Node in the Linked List.
	 * 
	 */
	public Node(Node<E> previous, E data, Node<E> next) {
		this.data = data;
		this.next = next;
		this.previous = previous;
	}

	/**
	 * Getter method to obtain a reference to the <b>Object</b> held by the Node.
	 * 
	 * @return	The <b>Object</b> held by the Node.
	 * 
	 */
	public E getData() {
		return this.data;
	}
	
	/**
	 * Setter method to set the reference to the <b>Object</b> held by the Node.
	 * 
	 * @param	data	The reference to the <b>Object</b> to be held by the Node.
	 * 
	 */
	public void setData(E data) {
		this.data = data;
	}
	
	/**
	 * Getter method to obtain a reference to the next Node.
	 * 
	 * @return	The next Node.
	 * 
	 */
	public Node<E> getNext() {
		return this.next;
	}
	
	/**
	 * Setter method to set the reference to the next Node.
	 * 
	 * @param	next	The reference to the next Node.
	 * 
	 */
	public void setNext(Node<E> next) {
		this.next = next;
	}
	
	/**
	 * Getter method to obtain a reference to the previous Node.
	 * 
	 * @return	The previous Node.
	 * 
	 */
	public Node<E> getPrevious() {
		return this.previous;
	}
	
	/**
	 * Setter method to set the reference to the previous Node.
	 * 
	 * @param	previous	The reference to the previous Node.
	 * 
	 */
	public void setPrevious(Node<E> previous) {
		this.previous = previous;
	}
}
